==> mauticGIT-Test-20251212_104643.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/16/16d02a455158c2769864c04c8ad0503a.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/DynamicContentBundle/Event/DynamicContentEvent.php */
class __TwigTemplate_f4566d61ab2e84cb2ef3224eadf30f4f extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\DynamicContentBundle\\Event;

use Mautic\\CoreBundle\\Event\\CommonEvent;
use Mautic\\DynamicContentBundle\\Entity\\DynamicContent;

class DynamicContentEvent extends CommonEvent
{
    /**
     * @param bool \$isNew
     */
    public function __construct(DynamicContent \$entity, \$isNew = false)
    {
        \$this->entity = \$entity;
        \$this->isNew  = \$isNew;
    }

    /**
     * @return DynamicContent
     */
    public function getDynamicContent()
    {
        return \$this->entity;
    }

    public function setDynamicContent(DynamicContent \$entity): void
    {
        \$this->entity = \$entity;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/DynamicContentBundle/Event/DynamicContentEvent.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/DynamicContentBundle/Event/DynamicContentEvent.php", "/var/www/mautic-ktn/app/bundles/DynamicContentBundle/Event/DynamicContentEvent.php");
    }
}

==> mauticGIT-Test-20260116_092227.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/16/16d02a455158c2769864c04c8ad0503a.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/DynamicContentBundle/Event/DynamicContentEvent.php */
class __TwigTemplate_f4566d61ab2e84cb2ef3224eadf30f4f extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\DynamicContentBundle\\Event;

use Mautic\\CoreBundle\\Event\\CommonEvent;
use Mautic\\DynamicContentBundle\\Entity\\DynamicContent;

class DynamicContentEvent extends CommonEvent
{
    /**
     * @param bool \$isNew
     */
    public function __construct(DynamicContent \$entity, \$isNew = false)
    {
        \$this->entity = \$entity;
        \$this->isNew  = \$isNew;
    }

    /**
     * @return DynamicContent
     */
    public function getDynamicContent()
    {
        return \$this->entity;
    }

    public function setDynamicContent(DynamicContent \$entity): void
    {
        \$this->entity = \$entity;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/DynamicContentBundle/Event/DynamicContentEvent.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/DynamicContentBundle/Event/DynamicContentEvent.php", "/var/www/html/mauticGIT-Test/app/bundles/DynamicContentBundle/Event/DynamicContentEvent.php");
    }
}
